import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import org.gui.JDirectoryDialog;

public class SplitItFrame extends JFrame
{
	private JTextField sourceFilePath, destFilePath;
	private JButton sourceBrowseButton, destBrowseButton;
	private JLabel fileSizeLabel;

	JRadioButton fixedSizeButton, floppySizeButton, fixedPartsButton;
	JRadioButton batchFileButton, rejoinUtilityButton;
	JCheckBox createZipFileButton;
	private	JDirectoryDialog directoryDialog;
	private JFileChooser fileChooser;
	private JButton splitButton, cancelButton;
	
	File sourceFile = null, destFile = null;
	
	SplitItFrame()
	{
		super("Split It v2.0");
		
		JPanel sourceFilePanel = new JPanel();
		sourceFilePanel.setLayout(new BorderLayout(5,5));
		sourceFilePath = new JTextField();
		sourceFilePath.setEditable(false);
		sourceFilePath.setBackground(new Color(255,255,255));
		sourceBrowseButton = new JButton("Browse");
		sourceBrowseButton.setMargin(new Insets(1,5,1,5));		
		fileSizeLabel = new JLabel("Source File Size : 0 Bytes");
		sourceFilePanel.add(sourceFilePath, BorderLayout.CENTER);
		sourceFilePanel.add(sourceBrowseButton, BorderLayout.EAST);		
		sourceFilePanel.add(fileSizeLabel, BorderLayout.SOUTH);				
		sourceFilePanel.setBorder(BorderFactory.createTitledBorder("Choose Source File"));
		
		JPanel sizeOptionsPanel = new JPanel();
		sizeOptionsPanel.setLayout(new BoxLayout(sizeOptionsPanel, BoxLayout.Y_AXIS));

		ButtonGroup buttonGroup1 = new ButtonGroup();
		floppySizeButton = new JRadioButton("Split to 1.44 MB size.");		
		floppySizeButton.setSelected(true);
		fixedSizeButton = new JRadioButton("I want to enter the size of splitted files.");
		fixedPartsButton = new JRadioButton("I want to enter the number of splitted files.");		
		buttonGroup1.add(floppySizeButton);
		buttonGroup1.add(fixedSizeButton);
		buttonGroup1.add(fixedPartsButton);
		
		createZipFileButton = new JCheckBox("Compress splitted files to save disk space.");

		sizeOptionsPanel.add(floppySizeButton);
		sizeOptionsPanel.add(fixedSizeButton);		
		sizeOptionsPanel.add(fixedPartsButton);		
		sizeOptionsPanel.add(createZipFileButton);		
		sizeOptionsPanel.setBorder(BorderFactory.createTitledBorder("Select the size of splitted files"));		
				
		JPanel rejoinOptionsPanel = new JPanel();
		rejoinOptionsPanel.setLayout(new BoxLayout(rejoinOptionsPanel, BoxLayout.Y_AXIS));
		
		ButtonGroup buttonGroup2 = new ButtonGroup();
		batchFileButton = new JRadioButton("Create a batch file (Requires Windows OS).");		
		rejoinUtilityButton = new JRadioButton("Create a rejoin utility (Requires Java Runtime 1.4x).");
		buttonGroup2.add(batchFileButton);
		buttonGroup2.add(rejoinUtilityButton);
		rejoinOptionsPanel.add(batchFileButton);
		rejoinOptionsPanel.add(rejoinUtilityButton);
		rejoinOptionsPanel.setBorder(BorderFactory.createTitledBorder("Select a rejoin option"));
				
		JPanel destFilePanel = new JPanel();
		destFilePanel.setLayout(new BorderLayout(5,5));
		destFilePath = new JTextField();
		destFilePath.setEditable(false);
		destFilePath.setBackground(new Color(255,255,255));
		destBrowseButton = new JButton("Browse");
		destBrowseButton.setMargin(new Insets(1,5,1,5));		
		destFilePanel.add(destFilePath, BorderLayout.CENTER);
		destFilePanel.add(destBrowseButton, BorderLayout.EAST);		
		destFilePanel.setBorder(BorderFactory.createTitledBorder("Choose Destination Folder"));
		
		JPanel centerPanel1 = new JPanel();
		centerPanel1.setLayout(new BorderLayout(5, 5));
		centerPanel1.add(sourceFilePanel, BorderLayout.NORTH);
		centerPanel1.add(sizeOptionsPanel, BorderLayout.CENTER);
		centerPanel1.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
		
		JPanel centerPanel2 = new JPanel();
		centerPanel2.setLayout(new BorderLayout(5, 5));
		centerPanel2.add(rejoinOptionsPanel, BorderLayout.CENTER);
		centerPanel2.add(destFilePanel, BorderLayout.SOUTH);
		centerPanel2.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));		
		
		JPanel centerPanel = new JPanel();
		centerPanel.setLayout(new BoxLayout(centerPanel, BoxLayout.Y_AXIS));
		centerPanel.add(centerPanel1);
		centerPanel.add(centerPanel2);
		
		JPanel southPanel = new JPanel();
		southPanel.setLayout(new FlowLayout(FlowLayout.RIGHT,7,5));
		splitButton = new JButton("Split It");
		cancelButton = new JButton("Close");		
		southPanel.add(splitButton);		
		southPanel.add(cancelButton);
		
		JLabel imageLabel = new JLabel(new ImageIcon(getClass().getResource("/images/logo.png")));
		getContentPane().setLayout(new BorderLayout(0,0));
		getContentPane().add(imageLabel, BorderLayout.NORTH);
		getContentPane().add(centerPanel, BorderLayout.CENTER);
		getContentPane().add(southPanel, BorderLayout.SOUTH);
		getRootPane().setDefaultButton(splitButton);
		rejoinUtilityButton.setSelected(true);
		
		addWindowListener(new WindowAdapter()
		{
			public void windowClosing(WindowEvent e)
			{
				SplitItFrame.this.dispose();
				System.exit(0);
			}
		});		
		
		sourceBrowseButton.addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent e)
			{
				if(fileChooser == null)
				{
					fileChooser = new JFileChooser();
					fileChooser.setDoubleBuffered(true);
				}
				int returnValue = fileChooser.showOpenDialog(SplitItFrame.this);
				if(returnValue == JFileChooser.APPROVE_OPTION)
				{
					sourceFile = fileChooser.getSelectedFile();
					sourceFilePath.setText(sourceFile.getAbsolutePath());
					fileSizeLabel.setText("Source File Size : "+sourceFile.length()+" Bytes");
				}	
			}
		});	
		
		destBrowseButton.addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent e)
			{
				if(directoryDialog == null)
				{
					directoryDialog = new JDirectoryDialog(SplitItFrame.this);
				}
				if(directoryDialog.showDirectoryDialog())
				{
					destFile = directoryDialog.getSelectedFolder();
					destFilePath.setText(destFile.getAbsolutePath());
				}	
			}
		});	
		
		createZipFileButton.addItemListener(new ItemListener()
		{
			public void itemStateChanged(ItemEvent e)
			{
				if(e.getStateChange()==ItemEvent.SELECTED)
				{
					rejoinUtilityButton.setSelected(true);
					batchFileButton.setEnabled(false);					
				}else
				{
					batchFileButton.setEnabled(true);		
				}	
			}
		});		
		
		cancelButton.addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent e)
			{
				SplitItFrame.this.dispose();
				System.exit(0);
			}
		});		
	}	
}